// Status implementation
// Copyright (C) 05.09.97 Marco Dettori and Oliver Obst
//
// $Id: status.C,v 0.2 1998/03/16 10:49:57 oliver Exp $

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

#include <iostream.h>

#include <qcolor.h>
#include <qwidget.h>
#include <qevent.h>

#include "status.h"

// --- public constructor -----------------------------------------------------
// Fleet :: Fleet
//              char    n       : number of ships a player owns
//              char   *lengths : array of lengths of the ships
//              short   stlen   : length of ship status display (in divisions)

Status :: Status( char n, char *lengths, short stlen,
                  QWidget *parent, const char *name )
        : QWidget( parent, name )
{
        ships           = n;
        statuswidth     = stlen;

        fleet = new ShipP[ n ];
        for (int i=0; i < ships; i++)
                fleet[ i ] = new Ships( black, lengths[ i ], this );
        
}

// --- public destructor ------------------------------------------------------
// virtual Status :: ~Status
//

Status :: ~Status()
{
        for (int i=0; i < ships; i++)
                delete fleet[ i ];
        delete fleet;
}

// --- public -----------------------------------------------------------------
// Status :: resetStatus

void Status :: resetStatus()
{
        for (int i=0; i < ships; i++) {
                fleet[ i ]->setAll( TriState::EMPTY );
                fleet[ i ]->setColor( black );
        }
}

// --- public -----------------------------------------------------------------
// Status :: setStatus( int nr )

void Status :: setStatus( int nr, bool colorize )
{
        if ( nr >= 0 ) {
                fleet[ nr ]->setAll();
                if ( colorize )
                        fleet[ nr ]->setColor( black );
        }

        if ( ++nr < ships && colorize )
                fleet[ nr ]->setColor( red );
}

// --- public -----------------------------------------------------------------
// Status :: setShip

void Status :: setShip( char len )
{
        for ( int i=0; i < ships; i++ )
                if ( fleet[ i ]->length() == len &&
                     fleet[ i ]->getAll() != TriState::CROSS ) {
                        fleet[ i ]->setAll( TriState::CROSS );
                        len = 0;
                }
}



// --- protected --------------------------------------------------------------
// Status :: resizeEvent
//              QResizeEvent *  : new and old sizes of widget

void Status :: resizeEvent( QResizeEvent * )
{
        short xfsize = width() / statuswidth;
        short yfsize = width() / (statuswidth - 1);
        short i, x, y;
        i = x = y = 0;

        while ( i < ships ) {
                fleet[ i ]->setGeometry( x * xfsize, y * yfsize,
                                         fleet[ i ]->length() * xfsize,
                                         xfsize );
                if ( ++i < ships ) {
                        x += fleet[ i - 1 ]->length() + 1;
                        if ( x > statuswidth - fleet[ i ]->length() ) {
                                x = 0;
                                y++;
                        }
                }
        }
}
